logLik.SemiParBIV: Extract the log likelihood for a fitted copula model
Description
It extracts the log-likelihood for a fitted gjrm model.
Usage
# S3 method for SemiParBIV
logLik(object, ...)
Arguments
...
Un-used for this function.
Details
Modification of the classic logLik which accounts for the estimated degrees of freedom used in gjrm.
This function is provided so that information criteria work correctly by using the correct number of degrees
of freedom.