print.cond.mv: Print a cond.mv object
Description
The print method for a cond.mv object.
Usage
# S3 method for cond.mv
print(x, ...)
Arguments
- x
cond.mv object produced by cond.mv().
- ...
Other arguments.
Details
print.cond.mv prints the lower confidence interval limit, estimated conditonal mean or variance and upper confidence interval limit.